complete -c dufs -s c -l config -d 'Specify configuration file' -r -F
complete -c dufs -s b -l bind -d 'Specify bind address or unix socket' -r
complete -c dufs -s p -l port -d 'Specify port to listen on [default: 5000]' -r
complete -c dufs -l path-prefix -d 'Specify a path prefix' -r
complete -c dufs -l hidden -d 'Hide paths from directory listings, e.g. tmp,*.log,*.lock' -r
complete -c dufs -s a -l auth -d 'Add auth roles, e.g. user:pass@/dir1:rw,/dir2' -r
complete -c dufs -l auth-method -d 'Select auth method' -r -f -a "basic\t''
digest\t''"
complete -c dufs -l assets -d 'Set the path to the assets directory for overriding the built-in assets' -r -F
complete -c dufs -l log-format -d 'Customize http log format' -r
complete -c dufs -l log-file -d 'Specify the file to save logs to, other than stdout/stderr' -r -F
complete -c dufs -l compress -d 'Set zip compress level [default: low]' -r -f -a "none\t''
low\t''
medium\t''
high\t''"
complete -c dufs -l completions -d 'Print shell completion script for <shell>' -r -f -a "bash\t''
elvish\t''
fish\t''
powershell\t''
zsh\t''"
complete -c dufs -l tls-cert -d 'Path to an SSL/TLS certificate to serve with HTTPS' -r -F
complete -c dufs -l tls-key -d 'Path to the SSL/TLS certificate\'s private key' -r -F
complete -c dufs -s A -l allow-all -d 'Allow all operations'
complete -c dufs -l allow-upload -d 'Allow upload files/folders'
complete -c dufs -l allow-delete -d 'Allow delete files/folders'
complete -c dufs -l allow-search -d 'Allow search files/folders'
complete -c dufs -l allow-symlink -d 'Allow symlink to files/folders outside root directory'
complete -c dufs -l allow-archive -d 'Allow download folders as archive file'
complete -c dufs -l enable-cors -d 'Enable CORS, sets `Access-Control-Allow-Origin: *`'
complete -c dufs -l render-index -d 'Serve index.html when requesting a directory, returns 404 if not found index.html'
complete -c dufs -l render-try-index -d 'Serve index.html when requesting a directory, returns directory listing if not found index.html'
complete -c dufs -l render-spa -d 'Serve SPA(Single Page Application)'
complete -c dufs -s h -l help -d 'Print help'
complete -c dufs -s V -l version -d 'Print version'
